/*=============================================================================
XMOTO

This file is part of XMOTO.

XMOTO is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

XMOTO is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with XMOTO; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
=============================================================================*/

#include "StatePreplayingCredits.h"
#include "StateCreditsMode.h"
#include "StateManager.h"

StatePreplayingCredits::StatePreplayingCredits(const std::string& i_id, const std::string i_replay)
: StatePreplayingReplay(i_id, i_replay, false) {
    m_name  = "StatePreplayingCredit";
}

StatePreplayingCredits::~StatePreplayingCredits() {
}

void StatePreplayingCredits::runPlaying() {
  StateManager::instance()->replaceState(new StateCreditsMode(getId(), m_universe, m_replay, m_replayBiker),
					 this->getId());
}

bool StatePreplayingCredits::shouldBeAnimated() const {
  return false;
}

bool StatePreplayingCredits::allowGhosts() {
  return false;
}
